@@ -47,7 +47,9 @@ qmidinetApplication::qmidinetApplication ( int& argc, char **argv, bool bGUI )
 {
 	if (bGUI) {
 	#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
+	#if QT_VERSION <  QT_VERSION_CHECK(6, 0, 0)
 		QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+	#endif
 	#endif
 		QApplication *pApp = new QApplication(argc, argv);
 	#if QT_VERSION >= QT_VERSION_CHECK(5, 1, 0)
@@ -68,20 +70,20 @@ qmidinetApplication::qmidinetApplication ( int& argc, char **argv, bool bGUI )
 
 #ifdef CONFIG_ALSA_MIDI
 	QObject::connect(
-		&m_udpd, SIGNAL(received(const QByteArray&, int)),
-		&m_alsa, SLOT(receive(const QByteArray&, int)));
+		&m_udpd, SIGNAL(received(QByteArray, int)),
+		&m_alsa, SLOT(receive(QByteArray, int)));
 	QObject::connect(
-		&m_alsa, SIGNAL(received(const QByteArray&, int)),
-		&m_udpd, SLOT(receive(const QByteArray&, int)));
+		&m_alsa, SIGNAL(received(QByteArray, int)),
+		&m_udpd, SLOT(receive(QByteArray, int)));
 #endif
 
 #ifdef CONFIG_JACK_MIDI
 	QObject::connect(
-		&m_udpd, SIGNAL(received(const QByteArray&, int)),
-		&m_jack, SLOT(receive(const QByteArray&, int)));
+		&m_udpd, SIGNAL(received(QByteArray, int)),
+		&m_jack, SLOT(receive(QByteArray, int)));
 	QObject::connect(
-		&m_jack, SIGNAL(received(const QByteArray&, int)),
-		&m_udpd, SLOT(receive(const QByteArray&, int)));
+		&m_jack, SIGNAL(received(QByteArray, int)),
+		&m_udpd, SLOT(receive(QByteArray, int)));
 	QObject::connect(&m_jack,
 		SIGNAL(shutdown()),
 		SLOT(shutdown()));
@@ -89,16 +91,16 @@ qmidinetApplication::qmidinetApplication ( int& argc, char **argv, bool bGUI )
 
 	if (m_pIcon) {
 		QObject::connect(
-			&m_udpd, SIGNAL(received(const QByteArray&, int)),
+			&m_udpd, SIGNAL(received(QByteArray, int)),
 			m_pIcon, SLOT(receiving()));
 	#ifdef CONFIG_ALSA_MIDI
 		QObject::connect(
-			&m_alsa, SIGNAL(received(const QByteArray&, int)),
+			&m_alsa, SIGNAL(received(QByteArray, int)),
 			m_pIcon, SLOT(sending()));
 	#endif
 	#ifdef CONFIG_JACK_MIDI
 		QObject::connect(
-			&m_jack, SIGNAL(received(const QByteArray&, int)),
+			&m_jack, SIGNAL(received(QByteArray, int)),
 			m_pIcon, SLOT(sending()));
 	#endif
 	}
@@ -327,6 +329,12 @@ void qmidinetSystemTrayIcon::about (void)
 		sText += "</font></small><br />\n";
 	}
 	sText += "<br />\n";
+	sText += tr("Using: Qt %1").arg(qVersion());
+#if defined(QT_STATIC)
+	sText += "-static";
+#endif
+	sText += "<br />\n";
+	sText += "<br />\n";
 	sText += tr("Website") + ": <a href=\"" QMIDINET_WEBSITE "\">" QMIDINET_WEBSITE "</a><br />\n";
 	sText += "<br />\n";
 	sText += "<small>";
